@@ -14,17 +14,19 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, Mapping, Type, Union, overload
+from typing import Any, Dict, Mapping, Sequence, Type, Union, overload
 
 from botocore.client import BaseClient, ClientMeta
 
 from .literals import (
     InsightTypeType,
     LocaleType,
+    OrganizationResourceCollectionTypeType,
     ResourceCollectionTypeType,
     UpdateResourceCollectionActionType,
 )
 from .paginator import (
+    DescribeOrganizationResourceCollectionHealthPaginator,
     DescribeResourceCollectionHealthPaginator,
     GetCostEstimationPaginator,
     GetResourceCollectionPaginator,
@@ -32,8 +34,10 @@ from .paginator import (
     ListEventsPaginator,
     ListInsightsPaginator,
     ListNotificationChannelsPaginator,
+    ListOrganizationInsightsPaginator,
     ListRecommendationsPaginator,
     SearchInsightsPaginator,
+    SearchOrganizationInsightsPaginator,
 )
 from .type_defs import (
     AddNotificationChannelResponseTypeDef,
@@ -43,6 +47,9 @@ from .type_defs import (
     DescribeAnomalyResponseTypeDef,
     DescribeFeedbackResponseTypeDef,
     DescribeInsightResponseTypeDef,
+    DescribeOrganizationHealthResponseTypeDef,
+    DescribeOrganizationOverviewResponseTypeDef,
+    DescribeOrganizationResourceCollectionHealthResponseTypeDef,
     DescribeResourceCollectionHealthResponseTypeDef,
     DescribeServiceIntegrationResponseTypeDef,
     GetCostEstimationResponseTypeDef,
@@ -54,10 +61,13 @@ from .type_defs import (
     ListInsightsResponseTypeDef,
     ListInsightsStatusFilterTypeDef,
     ListNotificationChannelsResponseTypeDef,
+    ListOrganizationInsightsResponseTypeDef,
     ListRecommendationsResponseTypeDef,
     NotificationChannelConfigTypeDef,
     SearchInsightsFiltersTypeDef,
     SearchInsightsResponseTypeDef,
+    SearchOrganizationInsightsFiltersTypeDef,
+    SearchOrganizationInsightsResponseTypeDef,
     StartTimeRangeTypeDef,
     UpdateResourceCollectionFilterTypeDef,
     UpdateServiceIntegrationConfigTypeDef,
@@ -93,7 +103,7 @@ class Exceptions:
 
 class DevOpsGuruClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html)
     """
 
@@ -111,7 +121,7 @@ class DevOpsGuruClient(BaseClient):
         """
         Adds a notification channel to DevOps Guru.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.add_notification_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.add_notification_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#add_notification_channel)
         """
 
@@ -119,16 +129,17 @@ class DevOpsGuruClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#can_paginate)
         """
 
     def describe_account_health(self) -> DescribeAccountHealthResponseTypeDef:
         """
         Returns the number of open reactive insights, the number of open proactive
-        insights, and the number of metrics analyzed in your AWS account.
+        insights, and the number of metrics analyzed in your Amazon Web Services
+        account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.describe_account_health)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.describe_account_health)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#describe_account_health)
         """
 
@@ -140,35 +151,78 @@ class DevOpsGuruClient(BaseClient):
         were created, the number of open proactive insights that were created, and the
         Mean Time to Recover (MTTR) for all closed reactive insights.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.describe_account_overview)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.describe_account_overview)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#describe_account_overview)
         """
 
-    def describe_anomaly(self, *, Id: str) -> DescribeAnomalyResponseTypeDef:
+    def describe_anomaly(self, *, Id: str, AccountId: str = ...) -> DescribeAnomalyResponseTypeDef:
         """
         Returns details about an anomaly that you specify using its ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.describe_anomaly)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.describe_anomaly)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#describe_anomaly)
         """
 
     def describe_feedback(self, *, InsightId: str = ...) -> DescribeFeedbackResponseTypeDef:
         """
-        Returns the most recent feedback submitted in the current AWS account and
-        Region.
+        Returns the most recent feedback submitted in the current Amazon Web Services
+        account and Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.describe_feedback)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.describe_feedback)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#describe_feedback)
         """
 
-    def describe_insight(self, *, Id: str) -> DescribeInsightResponseTypeDef:
+    def describe_insight(self, *, Id: str, AccountId: str = ...) -> DescribeInsightResponseTypeDef:
         """
         Returns details about an insight that you specify using its ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.describe_insight)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.describe_insight)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#describe_insight)
         """
 
+    def describe_organization_health(
+        self, *, AccountIds: Sequence[str] = ..., OrganizationalUnitIds: Sequence[str] = ...
+    ) -> DescribeOrganizationHealthResponseTypeDef:
+        """
+        Returns active insights, predictive insights, and resource hours analyzed in
+        last hour.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.describe_organization_health)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#describe_organization_health)
+        """
+
+    def describe_organization_overview(
+        self,
+        *,
+        FromTime: Union[datetime, str],
+        ToTime: Union[datetime, str] = ...,
+        AccountIds: Sequence[str] = ...,
+        OrganizationalUnitIds: Sequence[str] = ...
+    ) -> DescribeOrganizationOverviewResponseTypeDef:
+        """
+        Returns an overview of your organization's history based on the specified time
+        range.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.describe_organization_overview)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#describe_organization_overview)
+        """
+
+    def describe_organization_resource_collection_health(
+        self,
+        *,
+        OrganizationResourceCollectionType: OrganizationResourceCollectionTypeType,
+        AccountIds: Sequence[str] = ...,
+        OrganizationalUnitIds: Sequence[str] = ...,
+        NextToken: str = ...,
+        MaxResults: int = ...
+    ) -> DescribeOrganizationResourceCollectionHealthResponseTypeDef:
+        """
+        Provides an overview of your system's health.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.describe_organization_resource_collection_health)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#describe_organization_resource_collection_health)
+        """
+
     def describe_resource_collection_health(
         self, *, ResourceCollectionType: ResourceCollectionTypeType, NextToken: str = ...
     ) -> DescribeResourceCollectionHealthResponseTypeDef:
@@ -177,7 +231,7 @@ class DevOpsGuruClient(BaseClient):
         Mean Time to Recover (MTTR) for all closed insights in resource collections in
         your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.describe_resource_collection_health)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.describe_resource_collection_health)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#describe_resource_collection_health)
         """
 
@@ -185,7 +239,7 @@ class DevOpsGuruClient(BaseClient):
         """
         Returns the integration status of services that are integrated with DevOps Guru.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.describe_service_integration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.describe_service_integration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#describe_service_integration)
         """
 
@@ -199,16 +253,16 @@ class DevOpsGuruClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#generate_presigned_url)
         """
 
     def get_cost_estimation(self, *, NextToken: str = ...) -> GetCostEstimationResponseTypeDef:
         """
-        Returns an estimate of the monthly cost for DevOps Guru to analyze your AWS
-        resources.
+        Returns an estimate of the monthly cost for DevOps Guru to analyze your Amazon
+        Web Services resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.get_cost_estimation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.get_cost_estimation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#get_cost_estimation)
         """
 
@@ -216,9 +270,10 @@ class DevOpsGuruClient(BaseClient):
         self, *, ResourceCollectionType: ResourceCollectionTypeType, NextToken: str = ...
     ) -> GetResourceCollectionResponseTypeDef:
         """
-        Returns lists AWS resources that are of the specified resource collection type.
+        Returns lists Amazon Web Services resources that are of the specified resource
+        collection type.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.get_resource_collection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.get_resource_collection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#get_resource_collection)
         """
 
@@ -228,24 +283,30 @@ class DevOpsGuruClient(BaseClient):
         InsightId: str,
         StartTimeRange: "StartTimeRangeTypeDef" = ...,
         MaxResults: int = ...,
-        NextToken: str = ...
+        NextToken: str = ...,
+        AccountId: str = ...
     ) -> ListAnomaliesForInsightResponseTypeDef:
         """
         Returns a list of the anomalies that belong to an insight that you specify using
         its ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.list_anomalies_for_insight)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.list_anomalies_for_insight)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#list_anomalies_for_insight)
         """
 
     def list_events(
-        self, *, Filters: "ListEventsFiltersTypeDef", MaxResults: int = ..., NextToken: str = ...
+        self,
+        *,
+        Filters: "ListEventsFiltersTypeDef",
+        MaxResults: int = ...,
+        NextToken: str = ...,
+        AccountId: str = ...
     ) -> ListEventsResponseTypeDef:
         """
         Returns a list of the events emitted by the resources that are evaluated by
         DevOps Guru.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.list_events)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.list_events)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#list_events)
         """
 
@@ -257,9 +318,9 @@ class DevOpsGuruClient(BaseClient):
         NextToken: str = ...
     ) -> ListInsightsResponseTypeDef:
         """
-        Returns a list of insights in your AWS account.
+        Returns a list of insights in your Amazon Web Services account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.list_insights)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.list_insights)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#list_insights)
         """
 
@@ -269,17 +330,38 @@ class DevOpsGuruClient(BaseClient):
         """
         Returns a list of notification channels configured for DevOps Guru.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.list_notification_channels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.list_notification_channels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#list_notification_channels)
         """
 
+    def list_organization_insights(
+        self,
+        *,
+        StatusFilter: "ListInsightsStatusFilterTypeDef",
+        MaxResults: int = ...,
+        AccountIds: Sequence[str] = ...,
+        OrganizationalUnitIds: Sequence[str] = ...,
+        NextToken: str = ...
+    ) -> ListOrganizationInsightsResponseTypeDef:
+        """
+        Returns a list of insights associated with the account or OU Id.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.list_organization_insights)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#list_organization_insights)
+        """
+
     def list_recommendations(
-        self, *, InsightId: str, NextToken: str = ..., Locale: LocaleType = ...
+        self,
+        *,
+        InsightId: str,
+        NextToken: str = ...,
+        Locale: LocaleType = ...,
+        AccountId: str = ...
     ) -> ListRecommendationsResponseTypeDef:
         """
         Returns a list of a specified insight's recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.list_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.list_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#list_recommendations)
         """
 
@@ -287,7 +369,7 @@ class DevOpsGuruClient(BaseClient):
         """
         Collects customer feedback about the specified insight.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.put_feedback)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.put_feedback)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#put_feedback)
         """
 
@@ -295,7 +377,7 @@ class DevOpsGuruClient(BaseClient):
         """
         Removes a notification channel from DevOps Guru.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.remove_notification_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.remove_notification_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#remove_notification_channel)
         """
 
@@ -309,12 +391,29 @@ class DevOpsGuruClient(BaseClient):
         NextToken: str = ...
     ) -> SearchInsightsResponseTypeDef:
         """
-        Returns a list of insights in your AWS account.
+        Returns a list of insights in your Amazon Web Services account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.search_insights)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.search_insights)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#search_insights)
         """
 
+    def search_organization_insights(
+        self,
+        *,
+        AccountIds: Sequence[str],
+        StartTimeRange: "StartTimeRangeTypeDef",
+        Type: InsightTypeType,
+        Filters: "SearchOrganizationInsightsFiltersTypeDef" = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
+    ) -> SearchOrganizationInsightsResponseTypeDef:
+        """
+        Returns a list of insights in your organization.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.search_organization_insights)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#search_organization_insights)
+        """
+
     def start_cost_estimation(
         self,
         *,
@@ -322,10 +421,10 @@ class DevOpsGuruClient(BaseClient):
         ClientToken: str = ...
     ) -> Dict[str, Any]:
         """
-        Starts the creation of an estimate of the monthly cost to analyze your AWS
-        resources.
+        Starts the creation of an estimate of the monthly cost to analyze your Amazon
+        Web Services resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.start_cost_estimation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.start_cost_estimation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#start_cost_estimation)
         """
 
@@ -338,7 +437,7 @@ class DevOpsGuruClient(BaseClient):
         """
         Updates the collection of resources that DevOps Guru analyzes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.update_resource_collection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.update_resource_collection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#update_resource_collection)
         """
 
@@ -349,16 +448,25 @@ class DevOpsGuruClient(BaseClient):
         Enables or disables integration with a service that can be integrated with
         DevOps Guru.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Client.update_service_integration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Client.update_service_integration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client.html#update_service_integration)
         """
 
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["describe_organization_resource_collection_health"]
+    ) -> DescribeOrganizationResourceCollectionHealthPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Paginator.DescribeOrganizationResourceCollectionHealth)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#describeorganizationresourcecollectionhealthpaginator)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["describe_resource_collection_health"]
     ) -> DescribeResourceCollectionHealthPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Paginator.DescribeResourceCollectionHealth)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Paginator.DescribeResourceCollectionHealth)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#describeresourcecollectionhealthpaginator)
         """
 
@@ -367,7 +475,7 @@ class DevOpsGuruClient(BaseClient):
         self, operation_name: Literal["get_cost_estimation"]
     ) -> GetCostEstimationPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetCostEstimation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetCostEstimation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#getcostestimationpaginator)
         """
 
@@ -376,7 +484,7 @@ class DevOpsGuruClient(BaseClient):
         self, operation_name: Literal["get_resource_collection"]
     ) -> GetResourceCollectionPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetResourceCollection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetResourceCollection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#getresourcecollectionpaginator)
         """
 
@@ -385,21 +493,21 @@ class DevOpsGuruClient(BaseClient):
         self, operation_name: Literal["list_anomalies_for_insight"]
     ) -> ListAnomaliesForInsightPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListAnomaliesForInsight)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListAnomaliesForInsight)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listanomaliesforinsightpaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_events"]) -> ListEventsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListEvents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListEvents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listeventspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_insights"]) -> ListInsightsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListInsights)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListInsights)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listinsightspaginator)
         """
 
@@ -408,22 +516,40 @@ class DevOpsGuruClient(BaseClient):
         self, operation_name: Literal["list_notification_channels"]
     ) -> ListNotificationChannelsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListNotificationChannels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListNotificationChannels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listnotificationchannelspaginator)
         """
 
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_organization_insights"]
+    ) -> ListOrganizationInsightsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListOrganizationInsights)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listorganizationinsightspaginator)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["list_recommendations"]
     ) -> ListRecommendationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListRecommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListRecommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#listrecommendationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["search_insights"]) -> SearchInsightsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.0/reference/services/devops-guru.html#DevOpsGuru.Paginator.SearchInsights)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Paginator.SearchInsights)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#searchinsightspaginator)
         """
+
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["search_organization_insights"]
+    ) -> SearchOrganizationInsightsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.25/reference/services/devops-guru.html#DevOpsGuru.Paginator.SearchOrganizationInsights)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators.html#searchorganizationinsightspaginator)
+        """
